# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.background
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.networking
import winsdk.windows.networking.connectivity
import winsdk.windows.security.credentials
import winsdk.windows.security.cryptography.certificates
import winsdk.windows.storage.streams
import winsdk.windows.web

class ControlChannelTriggerResetReason(enum.IntEnum):
    FAST_USER_SWITCHED = 0
    LOW_POWER_EXIT = 1
    QUIET_HOURS_EXIT = 2
    APPLICATION_RESTART = 3

class ControlChannelTriggerResourceType(enum.IntEnum):
    REQUEST_SOFTWARE_SLOT = 0
    REQUEST_HARDWARE_SLOT = 1

class ControlChannelTriggerStatus(enum.IntEnum):
    HARDWARE_SLOT_REQUESTED = 0
    SOFTWARE_SLOT_ALLOCATED = 1
    HARDWARE_SLOT_ALLOCATED = 2
    POLICY_ERROR = 3
    SYSTEM_ERROR = 4
    TRANSPORT_DISCONNECTED = 5
    SERVICE_UNAVAILABLE = 6

class MessageWebSocketReceiveMode(enum.IntEnum):
    FULL_MESSAGE = 0
    PARTIAL_MESSAGE = 1

class SocketActivityConnectedStandbyAction(enum.IntEnum):
    DO_NOT_WAKE = 0
    WAKE = 1

class SocketActivityKind(enum.IntEnum):
    NONE = 0
    STREAM_SOCKET_LISTENER = 1
    DATAGRAM_SOCKET = 2
    STREAM_SOCKET = 3

class SocketActivityTriggerReason(enum.IntEnum):
    NONE = 0
    SOCKET_ACTIVITY = 1
    CONNECTION_ACCEPTED = 2
    KEEP_ALIVE_TIMER_EXPIRED = 3
    SOCKET_CLOSED = 4

class SocketErrorStatus(enum.IntEnum):
    UNKNOWN = 0
    OPERATION_ABORTED = 1
    HTTP_INVALID_SERVER_RESPONSE = 2
    CONNECTION_TIMED_OUT = 3
    ADDRESS_FAMILY_NOT_SUPPORTED = 4
    SOCKET_TYPE_NOT_SUPPORTED = 5
    HOST_NOT_FOUND = 6
    NO_DATA_RECORD_OF_REQUESTED_TYPE = 7
    NON_AUTHORITATIVE_HOST_NOT_FOUND = 8
    CLASS_TYPE_NOT_FOUND = 9
    ADDRESS_ALREADY_IN_USE = 10
    CANNOT_ASSIGN_REQUESTED_ADDRESS = 11
    CONNECTION_REFUSED = 12
    NETWORK_IS_UNREACHABLE = 13
    UNREACHABLE_HOST = 14
    NETWORK_IS_DOWN = 15
    NETWORK_DROPPED_CONNECTION_ON_RESET = 16
    SOFTWARE_CAUSED_CONNECTION_ABORT = 17
    CONNECTION_RESET_BY_PEER = 18
    HOST_IS_DOWN = 19
    NO_ADDRESSES_FOUND = 20
    TOO_MANY_OPEN_FILES = 21
    MESSAGE_TOO_LONG = 22
    CERTIFICATE_EXPIRED = 23
    CERTIFICATE_UNTRUSTED_ROOT = 24
    CERTIFICATE_COMMON_NAME_IS_INCORRECT = 25
    CERTIFICATE_WRONG_USAGE = 26
    CERTIFICATE_REVOKED = 27
    CERTIFICATE_NO_REVOCATION_CHECK = 28
    CERTIFICATE_REVOCATION_SERVER_OFFLINE = 29
    CERTIFICATE_IS_INVALID = 30

class SocketMessageType(enum.IntEnum):
    BINARY = 0
    UTF8 = 1

class SocketProtectionLevel(enum.IntEnum):
    PLAIN_SOCKET = 0
    SSL = 1
    SSL_ALLOW_NULL_ENCRYPTION = 2
    BLUETOOTH_ENCRYPTION_ALLOW_NULL_AUTHENTICATION = 3
    BLUETOOTH_ENCRYPTION_WITH_AUTHENTICATION = 4
    SSL3_ALLOW_WEAK_ENCRYPTION = 5
    TLS10 = 6
    TLS11 = 7
    TLS12 = 8
    UNSPECIFIED = 9

class SocketQualityOfService(enum.IntEnum):
    NORMAL = 0
    LOW_LATENCY = 1

class SocketSslErrorSeverity(enum.IntEnum):
    NONE = 0
    IGNORABLE = 1
    FATAL = 2

Self = typing.TypeVar('Self')

class BandwidthStatistics:
    outbound_bits_per_second: winsdk.system.UInt64
    inbound_bits_per_second: winsdk.system.UInt64
    outbound_bits_per_second_instability: winsdk.system.UInt64
    inbound_bits_per_second_instability: winsdk.system.UInt64
    outbound_bandwidth_peaked: winsdk.system.Boolean
    inbound_bandwidth_peaked: winsdk.system.Boolean
    def __new__(cls: typing.Type[BandwidthStatistics], outbound_bits_per_second: winsdk.system.UInt64, inbound_bits_per_second: winsdk.system.UInt64, outbound_bits_per_second_instability: winsdk.system.UInt64, inbound_bits_per_second_instability: winsdk.system.UInt64, outbound_bandwidth_peaked: winsdk.system.Boolean, inbound_bandwidth_peaked: winsdk.system.Boolean) -> BandwidthStatistics: ...

class RoundTripTimeStatistics:
    variance: winsdk.system.UInt32
    max: winsdk.system.UInt32
    min: winsdk.system.UInt32
    sum: winsdk.system.UInt32
    def __new__(cls: typing.Type[RoundTripTimeStatistics], variance: winsdk.system.UInt32, max: winsdk.system.UInt32, min: winsdk.system.UInt32, sum: winsdk.system.UInt32) -> RoundTripTimeStatistics: ...

class ControlChannelTrigger(winsdk.system.Object):
    server_keep_alive_interval_in_minutes: winsdk.system.UInt32
    control_channel_trigger_id: str
    current_keep_alive_interval_in_minutes: winsdk.system.UInt32
    keep_alive_trigger: typing.Optional[winsdk.windows.applicationmodel.background.IBackgroundTrigger]
    push_notification_trigger: typing.Optional[winsdk.windows.applicationmodel.background.IBackgroundTrigger]
    transport_object: typing.Optional[winsdk.system.Object]
    is_wake_from_low_power_supported: winsdk.system.Boolean
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ControlChannelTrigger: ...
    @typing.overload
    def __new__(cls: typing.Type[ControlChannelTrigger], channel_id: str, server_keep_alive_interval_in_minutes: winsdk.system.UInt32) -> ControlChannelTrigger:...
    @typing.overload
    def __new__(cls: typing.Type[ControlChannelTrigger], channel_id: str, server_keep_alive_interval_in_minutes: winsdk.system.UInt32, resource_request_type: ControlChannelTriggerResourceType) -> ControlChannelTrigger:...
    def close(self) -> None: ...
    def decrease_network_keep_alive_interval(self) -> None: ...
    def flush_transport(self) -> None: ...
    def using_transport(self, transport: typing.Optional[winsdk.system.Object]) -> None: ...
    def wait_for_push_enabled(self) -> ControlChannelTriggerStatus: ...

class DatagramSocket(winsdk.system.Object):
    control: typing.Optional[DatagramSocketControl]
    information: typing.Optional[DatagramSocketInformation]
    output_stream: typing.Optional[winsdk.windows.storage.streams.IOutputStream]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DatagramSocket: ...
    def __new__(cls: typing.Type[DatagramSocket]) -> DatagramSocket:...
    def bind_endpoint_async(self, local_host_name: typing.Optional[winsdk.windows.networking.HostName], local_service_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def bind_service_name_async(self, local_service_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def bind_service_name_async(self, local_service_name: str, adapter: typing.Optional[winsdk.windows.networking.connectivity.NetworkAdapter]) -> winsdk.windows.foundation.IAsyncAction: ...
    def cancel_i_o_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def close(self) -> None: ...
    @typing.overload
    def connect_async(self, endpoint_pair: typing.Optional[winsdk.windows.networking.EndpointPair]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def connect_async(self, remote_host_name: typing.Optional[winsdk.windows.networking.HostName], remote_service_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def enable_transfer_ownership(self, task_id: winsdk.system.Guid) -> None: ...
    @typing.overload
    def enable_transfer_ownership(self, task_id: winsdk.system.Guid, connected_standby_action: SocketActivityConnectedStandbyAction) -> None: ...
    @typing.overload
    @staticmethod
    def get_endpoint_pairs_async(remote_host_name: typing.Optional[winsdk.windows.networking.HostName], remote_service_name: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.networking.EndpointPair]]: ...
    @typing.overload
    @staticmethod
    def get_endpoint_pairs_async(remote_host_name: typing.Optional[winsdk.windows.networking.HostName], remote_service_name: str, sort_options: winsdk.windows.networking.HostNameSortOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.networking.EndpointPair]]: ...
    @typing.overload
    def get_output_stream_async(self, endpoint_pair: typing.Optional[winsdk.windows.networking.EndpointPair]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IOutputStream]: ...
    @typing.overload
    def get_output_stream_async(self, remote_host_name: typing.Optional[winsdk.windows.networking.HostName], remote_service_name: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IOutputStream]: ...
    def join_multicast_group(self, host: typing.Optional[winsdk.windows.networking.HostName]) -> None: ...
    @typing.overload
    def transfer_ownership(self, socket_id: str) -> None: ...
    @typing.overload
    def transfer_ownership(self, socket_id: str, data: typing.Optional[SocketActivityContext]) -> None: ...
    @typing.overload
    def transfer_ownership(self, socket_id: str, data: typing.Optional[SocketActivityContext], keep_alive_time: datetime.timedelta) -> None: ...
    def add_message_received(self, event_handler: winsdk.windows.foundation.TypedEventHandler[DatagramSocket, DatagramSocketMessageReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_message_received(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class DatagramSocketControl(winsdk.system.Object):
    quality_of_service: SocketQualityOfService
    outbound_unicast_hop_limit: winsdk.system.UInt8
    inbound_buffer_size_in_bytes: winsdk.system.UInt32
    dont_fragment: winsdk.system.Boolean
    multicast_only: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DatagramSocketControl: ...

class DatagramSocketInformation(winsdk.system.Object):
    local_address: typing.Optional[winsdk.windows.networking.HostName]
    local_port: str
    remote_address: typing.Optional[winsdk.windows.networking.HostName]
    remote_port: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DatagramSocketInformation: ...

class DatagramSocketMessageReceivedEventArgs(winsdk.system.Object):
    local_address: typing.Optional[winsdk.windows.networking.HostName]
    remote_address: typing.Optional[winsdk.windows.networking.HostName]
    remote_port: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DatagramSocketMessageReceivedEventArgs: ...
    def get_data_reader(self) -> typing.Optional[winsdk.windows.storage.streams.DataReader]: ...
    def get_data_stream(self) -> typing.Optional[winsdk.windows.storage.streams.IInputStream]: ...

class MessageWebSocket(winsdk.system.Object):
    control: typing.Optional[MessageWebSocketControl]
    information: typing.Optional[MessageWebSocketInformation]
    output_stream: typing.Optional[winsdk.windows.storage.streams.IOutputStream]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MessageWebSocket: ...
    def __new__(cls: typing.Type[MessageWebSocket]) -> MessageWebSocket:...
    @typing.overload
    def close(self) -> None: ...
    @typing.overload
    def close(self, code: winsdk.system.UInt16, reason: str) -> None: ...
    def connect_async(self, uri: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncAction: ...
    def send_final_frame_async(self, data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...
    def send_nonfinal_frame_async(self, data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...
    def set_request_header(self, header_name: str, header_value: str) -> None: ...
    def add_message_received(self, event_handler: winsdk.windows.foundation.TypedEventHandler[MessageWebSocket, MessageWebSocketMessageReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_message_received(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_closed(self, event_handler: winsdk.windows.foundation.TypedEventHandler[IWebSocket, WebSocketClosedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_closed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_server_custom_validation_requested(self, event_handler: winsdk.windows.foundation.TypedEventHandler[MessageWebSocket, WebSocketServerCustomValidationRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_server_custom_validation_requested(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MessageWebSocketControl(winsdk.system.Object):
    message_type: SocketMessageType
    max_message_size: winsdk.system.UInt32
    receive_mode: MessageWebSocketReceiveMode
    desired_unsolicited_pong_interval: datetime.timedelta
    client_certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]
    actual_unsolicited_pong_interval: datetime.timedelta
    server_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    proxy_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    outbound_buffer_size_in_bytes: winsdk.system.UInt32
    supported_protocols: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    ignorable_server_certificate_errors: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.security.cryptography.certificates.ChainValidationResult]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MessageWebSocketControl: ...

class MessageWebSocketInformation(winsdk.system.Object):
    bandwidth_statistics: BandwidthStatistics
    local_address: typing.Optional[winsdk.windows.networking.HostName]
    protocol: str
    server_certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]
    server_certificate_error_severity: SocketSslErrorSeverity
    server_certificate_errors: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.cryptography.certificates.ChainValidationResult]]
    server_intermediate_certificates: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.cryptography.certificates.Certificate]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MessageWebSocketInformation: ...

class MessageWebSocketMessageReceivedEventArgs(winsdk.system.Object):
    message_type: SocketMessageType
    is_message_complete: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MessageWebSocketMessageReceivedEventArgs: ...
    def get_data_reader(self) -> typing.Optional[winsdk.windows.storage.streams.DataReader]: ...
    def get_data_stream(self) -> typing.Optional[winsdk.windows.storage.streams.IInputStream]: ...

class ServerMessageWebSocket(winsdk.system.Object):
    control: typing.Optional[ServerMessageWebSocketControl]
    information: typing.Optional[ServerMessageWebSocketInformation]
    output_stream: typing.Optional[winsdk.windows.storage.streams.IOutputStream]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ServerMessageWebSocket: ...
    @typing.overload
    def close(self) -> None: ...
    @typing.overload
    def close(self, code: winsdk.system.UInt16, reason: str) -> None: ...
    def add_closed(self, value: winsdk.windows.foundation.TypedEventHandler[ServerMessageWebSocket, WebSocketClosedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_closed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_message_received(self, value: winsdk.windows.foundation.TypedEventHandler[ServerMessageWebSocket, MessageWebSocketMessageReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_message_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class ServerMessageWebSocketControl(winsdk.system.Object):
    message_type: SocketMessageType
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ServerMessageWebSocketControl: ...

class ServerMessageWebSocketInformation(winsdk.system.Object):
    bandwidth_statistics: BandwidthStatistics
    local_address: typing.Optional[winsdk.windows.networking.HostName]
    protocol: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ServerMessageWebSocketInformation: ...

class ServerStreamWebSocket(winsdk.system.Object):
    information: typing.Optional[ServerStreamWebSocketInformation]
    input_stream: typing.Optional[winsdk.windows.storage.streams.IInputStream]
    output_stream: typing.Optional[winsdk.windows.storage.streams.IOutputStream]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ServerStreamWebSocket: ...
    @typing.overload
    def close(self) -> None: ...
    @typing.overload
    def close(self, code: winsdk.system.UInt16, reason: str) -> None: ...
    def add_closed(self, value: winsdk.windows.foundation.TypedEventHandler[ServerStreamWebSocket, WebSocketClosedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_closed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class ServerStreamWebSocketInformation(winsdk.system.Object):
    bandwidth_statistics: BandwidthStatistics
    local_address: typing.Optional[winsdk.windows.networking.HostName]
    protocol: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ServerStreamWebSocketInformation: ...

class SocketActivityContext(winsdk.system.Object):
    data: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SocketActivityContext: ...
    def __new__(cls: typing.Type[SocketActivityContext], data: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> SocketActivityContext:...

class SocketActivityInformation(winsdk.system.Object):
    context: typing.Optional[SocketActivityContext]
    datagram_socket: typing.Optional[DatagramSocket]
    id: str
    socket_kind: SocketActivityKind
    stream_socket: typing.Optional[StreamSocket]
    stream_socket_listener: typing.Optional[StreamSocketListener]
    task_id: winsdk.system.Guid
    all_sockets: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IMapView[str, SocketActivityInformation]]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SocketActivityInformation: ...

class SocketActivityTriggerDetails(winsdk.system.Object):
    reason: SocketActivityTriggerReason
    socket_information: typing.Optional[SocketActivityInformation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SocketActivityTriggerDetails: ...

class SocketError(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SocketError: ...
    @staticmethod
    def get_status(hresult: winsdk.system.Int32) -> SocketErrorStatus: ...

class StreamSocket(winsdk.system.Object):
    control: typing.Optional[StreamSocketControl]
    information: typing.Optional[StreamSocketInformation]
    input_stream: typing.Optional[winsdk.windows.storage.streams.IInputStream]
    output_stream: typing.Optional[winsdk.windows.storage.streams.IOutputStream]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StreamSocket: ...
    def __new__(cls: typing.Type[StreamSocket]) -> StreamSocket:...
    def cancel_i_o_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def close(self) -> None: ...
    @typing.overload
    def connect_async(self, endpoint_pair: typing.Optional[winsdk.windows.networking.EndpointPair]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def connect_async(self, remote_host_name: typing.Optional[winsdk.windows.networking.HostName], remote_service_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def connect_async(self, remote_host_name: typing.Optional[winsdk.windows.networking.HostName], remote_service_name: str, protection_level: SocketProtectionLevel) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def connect_async(self, remote_host_name: typing.Optional[winsdk.windows.networking.HostName], remote_service_name: str, protection_level: SocketProtectionLevel, adapter: typing.Optional[winsdk.windows.networking.connectivity.NetworkAdapter]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def enable_transfer_ownership(self, task_id: winsdk.system.Guid) -> None: ...
    @typing.overload
    def enable_transfer_ownership(self, task_id: winsdk.system.Guid, connected_standby_action: SocketActivityConnectedStandbyAction) -> None: ...
    @typing.overload
    @staticmethod
    def get_endpoint_pairs_async(remote_host_name: typing.Optional[winsdk.windows.networking.HostName], remote_service_name: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.networking.EndpointPair]]: ...
    @typing.overload
    @staticmethod
    def get_endpoint_pairs_async(remote_host_name: typing.Optional[winsdk.windows.networking.HostName], remote_service_name: str, sort_options: winsdk.windows.networking.HostNameSortOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.networking.EndpointPair]]: ...
    @typing.overload
    def transfer_ownership(self, socket_id: str) -> None: ...
    @typing.overload
    def transfer_ownership(self, socket_id: str, data: typing.Optional[SocketActivityContext]) -> None: ...
    @typing.overload
    def transfer_ownership(self, socket_id: str, data: typing.Optional[SocketActivityContext], keep_alive_time: datetime.timedelta) -> None: ...
    def upgrade_to_ssl_async(self, protection_level: SocketProtectionLevel, validation_host_name: typing.Optional[winsdk.windows.networking.HostName]) -> winsdk.windows.foundation.IAsyncAction: ...

class StreamSocketControl(winsdk.system.Object):
    quality_of_service: SocketQualityOfService
    outbound_unicast_hop_limit: winsdk.system.UInt8
    outbound_buffer_size_in_bytes: winsdk.system.UInt32
    no_delay: winsdk.system.Boolean
    keep_alive: winsdk.system.Boolean
    ignorable_server_certificate_errors: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.security.cryptography.certificates.ChainValidationResult]]
    serialize_connection_attempts: winsdk.system.Boolean
    client_certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]
    min_protection_level: SocketProtectionLevel
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StreamSocketControl: ...

class StreamSocketInformation(winsdk.system.Object):
    bandwidth_statistics: BandwidthStatistics
    local_address: typing.Optional[winsdk.windows.networking.HostName]
    local_port: str
    protection_level: SocketProtectionLevel
    remote_address: typing.Optional[winsdk.windows.networking.HostName]
    remote_host_name: typing.Optional[winsdk.windows.networking.HostName]
    remote_port: str
    remote_service_name: str
    round_trip_time_statistics: RoundTripTimeStatistics
    session_key: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    server_certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]
    server_certificate_error_severity: SocketSslErrorSeverity
    server_certificate_errors: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.cryptography.certificates.ChainValidationResult]]
    server_intermediate_certificates: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.cryptography.certificates.Certificate]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StreamSocketInformation: ...

class StreamSocketListener(winsdk.system.Object):
    control: typing.Optional[StreamSocketListenerControl]
    information: typing.Optional[StreamSocketListenerInformation]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StreamSocketListener: ...
    def __new__(cls: typing.Type[StreamSocketListener]) -> StreamSocketListener:...
    def bind_endpoint_async(self, local_host_name: typing.Optional[winsdk.windows.networking.HostName], local_service_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def bind_service_name_async(self, local_service_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def bind_service_name_async(self, local_service_name: str, protection_level: SocketProtectionLevel) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def bind_service_name_async(self, local_service_name: str, protection_level: SocketProtectionLevel, adapter: typing.Optional[winsdk.windows.networking.connectivity.NetworkAdapter]) -> winsdk.windows.foundation.IAsyncAction: ...
    def cancel_i_o_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def close(self) -> None: ...
    @typing.overload
    def enable_transfer_ownership(self, task_id: winsdk.system.Guid) -> None: ...
    @typing.overload
    def enable_transfer_ownership(self, task_id: winsdk.system.Guid, connected_standby_action: SocketActivityConnectedStandbyAction) -> None: ...
    @typing.overload
    def transfer_ownership(self, socket_id: str) -> None: ...
    @typing.overload
    def transfer_ownership(self, socket_id: str, data: typing.Optional[SocketActivityContext]) -> None: ...
    def add_connection_received(self, event_handler: winsdk.windows.foundation.TypedEventHandler[StreamSocketListener, StreamSocketListenerConnectionReceivedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_connection_received(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class StreamSocketListenerConnectionReceivedEventArgs(winsdk.system.Object):
    socket: typing.Optional[StreamSocket]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StreamSocketListenerConnectionReceivedEventArgs: ...

class StreamSocketListenerControl(winsdk.system.Object):
    quality_of_service: SocketQualityOfService
    outbound_unicast_hop_limit: winsdk.system.UInt8
    outbound_buffer_size_in_bytes: winsdk.system.UInt32
    no_delay: winsdk.system.Boolean
    keep_alive: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StreamSocketListenerControl: ...

class StreamSocketListenerInformation(winsdk.system.Object):
    local_port: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StreamSocketListenerInformation: ...

class StreamWebSocket(winsdk.system.Object):
    control: typing.Optional[StreamWebSocketControl]
    information: typing.Optional[StreamWebSocketInformation]
    input_stream: typing.Optional[winsdk.windows.storage.streams.IInputStream]
    output_stream: typing.Optional[winsdk.windows.storage.streams.IOutputStream]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StreamWebSocket: ...
    def __new__(cls: typing.Type[StreamWebSocket]) -> StreamWebSocket:...
    @typing.overload
    def close(self) -> None: ...
    @typing.overload
    def close(self, code: winsdk.system.UInt16, reason: str) -> None: ...
    def connect_async(self, uri: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncAction: ...
    def set_request_header(self, header_name: str, header_value: str) -> None: ...
    def add_closed(self, event_handler: winsdk.windows.foundation.TypedEventHandler[IWebSocket, WebSocketClosedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_closed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_server_custom_validation_requested(self, event_handler: winsdk.windows.foundation.TypedEventHandler[StreamWebSocket, WebSocketServerCustomValidationRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_server_custom_validation_requested(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class StreamWebSocketControl(winsdk.system.Object):
    no_delay: winsdk.system.Boolean
    desired_unsolicited_pong_interval: datetime.timedelta
    client_certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]
    actual_unsolicited_pong_interval: datetime.timedelta
    server_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    proxy_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    outbound_buffer_size_in_bytes: winsdk.system.UInt32
    supported_protocols: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    ignorable_server_certificate_errors: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.security.cryptography.certificates.ChainValidationResult]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StreamWebSocketControl: ...

class StreamWebSocketInformation(winsdk.system.Object):
    bandwidth_statistics: BandwidthStatistics
    local_address: typing.Optional[winsdk.windows.networking.HostName]
    protocol: str
    server_certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]
    server_certificate_error_severity: SocketSslErrorSeverity
    server_certificate_errors: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.cryptography.certificates.ChainValidationResult]]
    server_intermediate_certificates: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.cryptography.certificates.Certificate]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StreamWebSocketInformation: ...

class WebSocketClosedEventArgs(winsdk.system.Object):
    code: winsdk.system.UInt16
    reason: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebSocketClosedEventArgs: ...

class WebSocketError(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebSocketError: ...
    @staticmethod
    def get_status(hresult: winsdk.system.Int32) -> winsdk.windows.web.WebErrorStatus: ...

class WebSocketKeepAlive(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebSocketKeepAlive: ...
    def __new__(cls: typing.Type[WebSocketKeepAlive]) -> WebSocketKeepAlive:...
    def run(self, task_instance: typing.Optional[winsdk.windows.applicationmodel.background.IBackgroundTaskInstance]) -> None: ...

class WebSocketServerCustomValidationRequestedEventArgs(winsdk.system.Object):
    server_certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]
    server_certificate_error_severity: SocketSslErrorSeverity
    server_certificate_errors: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.cryptography.certificates.ChainValidationResult]]
    server_intermediate_certificates: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.cryptography.certificates.Certificate]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebSocketServerCustomValidationRequestedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...
    def reject(self) -> None: ...

class IControlChannelTriggerEventDetails(winsdk.system.Object):
    control_channel_trigger: typing.Optional[ControlChannelTrigger]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IControlChannelTriggerEventDetails: ...

class IControlChannelTriggerResetEventDetails(winsdk.system.Object):
    hardware_slot_reset: winsdk.system.Boolean
    reset_reason: ControlChannelTriggerResetReason
    software_slot_reset: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IControlChannelTriggerResetEventDetails: ...

class IWebSocket(winsdk.system.Object):
    output_stream: typing.Optional[winsdk.windows.storage.streams.IOutputStream]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebSocket: ...
    @typing.overload
    def close(self, code: winsdk.system.UInt16, reason: str) -> None: ...
    @typing.overload
    def close(self) -> None: ...
    def connect_async(self, uri: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncAction: ...
    def set_request_header(self, header_name: str, header_value: str) -> None: ...
    def add_closed(self, event_handler: winsdk.windows.foundation.TypedEventHandler[IWebSocket, WebSocketClosedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_closed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class IWebSocketControl(winsdk.system.Object):
    outbound_buffer_size_in_bytes: winsdk.system.UInt32
    proxy_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    server_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    supported_protocols: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebSocketControl: ...

class IWebSocketControl2(winsdk.system.Object):
    ignorable_server_certificate_errors: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.security.cryptography.certificates.ChainValidationResult]]
    outbound_buffer_size_in_bytes: winsdk.system.UInt32
    proxy_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    server_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    supported_protocols: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebSocketControl2: ...

class IWebSocketInformation(winsdk.system.Object):
    bandwidth_statistics: BandwidthStatistics
    local_address: typing.Optional[winsdk.windows.networking.HostName]
    protocol: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebSocketInformation: ...

class IWebSocketInformation2(winsdk.system.Object):
    server_certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]
    server_certificate_error_severity: SocketSslErrorSeverity
    server_certificate_errors: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.cryptography.certificates.ChainValidationResult]]
    server_intermediate_certificates: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.cryptography.certificates.Certificate]]
    bandwidth_statistics: BandwidthStatistics
    local_address: typing.Optional[winsdk.windows.networking.HostName]
    protocol: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebSocketInformation2: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.security.enterprisedata
import winsdk.windows.storage
import winsdk.windows.storage.streams
import winsdk.windows.ui

class ClipboardHistoryItemsResultStatus(enum.IntEnum):
    SUCCESS = 0
    ACCESS_DENIED = 1
    CLIPBOARD_HISTORY_DISABLED = 2

class DataPackageOperation(enum.IntFlag):
    NONE = 0
    COPY = 0x1
    MOVE = 0x2
    LINK = 0x4

class SetHistoryItemAsContentStatus(enum.IntEnum):
    SUCCESS = 0
    ACCESS_DENIED = 1
    ITEM_DELETED = 2

class ShareUITheme(enum.IntEnum):
    DEFAULT = 0
    LIGHT = 1
    DARK = 2

Self = typing.TypeVar('Self')

class Clipboard(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Clipboard: ...
    @staticmethod
    def clear() -> None: ...
    @staticmethod
    def clear_history() -> winsdk.system.Boolean: ...
    @staticmethod
    def delete_item_from_history(item: typing.Optional[ClipboardHistoryItem]) -> winsdk.system.Boolean: ...
    @staticmethod
    def flush() -> None: ...
    @staticmethod
    def get_content() -> typing.Optional[DataPackageView]: ...
    @staticmethod
    def get_history_items_async() -> winsdk.windows.foundation.IAsyncOperation[ClipboardHistoryItemsResult]: ...
    @staticmethod
    def is_history_enabled() -> winsdk.system.Boolean: ...
    @staticmethod
    def is_roaming_enabled() -> winsdk.system.Boolean: ...
    @staticmethod
    def set_content(content: typing.Optional[DataPackage]) -> None: ...
    @staticmethod
    def set_content_with_options(content: typing.Optional[DataPackage], options: typing.Optional[ClipboardContentOptions]) -> winsdk.system.Boolean: ...
    @staticmethod
    def set_history_item_as_content(item: typing.Optional[ClipboardHistoryItem]) -> SetHistoryItemAsContentStatus: ...
    @staticmethod
    def add_history_changed(handler: winsdk.windows.foundation.EventHandler[ClipboardHistoryChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_history_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_history_enabled_changed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_history_enabled_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_roaming_enabled_changed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_roaming_enabled_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_content_changed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_content_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class ClipboardContentOptions(winsdk.system.Object):
    is_roamable: winsdk.system.Boolean
    is_allowed_in_history: winsdk.system.Boolean
    history_formats: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    roaming_formats: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ClipboardContentOptions: ...
    def __new__(cls: typing.Type[ClipboardContentOptions]) -> ClipboardContentOptions:...

class ClipboardHistoryChangedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ClipboardHistoryChangedEventArgs: ...

class ClipboardHistoryItem(winsdk.system.Object):
    content: typing.Optional[DataPackageView]
    id: str
    timestamp: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ClipboardHistoryItem: ...

class ClipboardHistoryItemsResult(winsdk.system.Object):
    items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[ClipboardHistoryItem]]
    status: ClipboardHistoryItemsResultStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ClipboardHistoryItemsResult: ...

class DataPackage(winsdk.system.Object):
    requested_operation: DataPackageOperation
    properties: typing.Optional[DataPackagePropertySet]
    resource_map: typing.Optional[winsdk.windows.foundation.collections.IMap[str, winsdk.windows.storage.streams.RandomAccessStreamReference]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataPackage: ...
    def __new__(cls: typing.Type[DataPackage]) -> DataPackage:...
    def get_view(self) -> typing.Optional[DataPackageView]: ...
    def set_application_link(self, value: typing.Optional[winsdk.windows.foundation.Uri]) -> None: ...
    def set_bitmap(self, value: typing.Optional[winsdk.windows.storage.streams.RandomAccessStreamReference]) -> None: ...
    def set_data(self, format_id: str, value: typing.Optional[winsdk.system.Object]) -> None: ...
    def set_data_provider(self, format_id: str, delay_renderer: typing.Optional[DataProviderHandler]) -> None: ...
    def set_html_format(self, value: str) -> None: ...
    def set_rtf(self, value: str) -> None: ...
    @typing.overload
    def set_storage_items(self, value: typing.Iterable[winsdk.windows.storage.IStorageItem]) -> None: ...
    @typing.overload
    def set_storage_items(self, value: typing.Iterable[winsdk.windows.storage.IStorageItem], read_only: winsdk.system.Boolean) -> None: ...
    def set_text(self, value: str) -> None: ...
    def set_uri(self, value: typing.Optional[winsdk.windows.foundation.Uri]) -> None: ...
    def set_web_link(self, value: typing.Optional[winsdk.windows.foundation.Uri]) -> None: ...
    def add_destroyed(self, handler: winsdk.windows.foundation.TypedEventHandler[DataPackage, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_destroyed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_operation_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[DataPackage, OperationCompletedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_operation_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_share_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[DataPackage, ShareCompletedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_share_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_share_canceled(self, handler: winsdk.windows.foundation.TypedEventHandler[DataPackage, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_share_canceled(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class DataPackagePropertySet(winsdk.system.Object, typing.MutableMapping[str, winsdk.system.Object]):
    title: str
    thumbnail: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    description: str
    application_name: str
    application_listing_uri: typing.Optional[winsdk.windows.foundation.Uri]
    file_types: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    square30x30_logo: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    package_family_name: str
    logo_background_color: winsdk.windows.ui.Color
    content_source_web_link: typing.Optional[winsdk.windows.foundation.Uri]
    content_source_application_link: typing.Optional[winsdk.windows.foundation.Uri]
    enterprise_id: str
    content_source_user_activity_json: str
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[str]: ...
    def __contains__(self, key: object) -> bool:...
    def __setitem__(self, key: str, value: winsdk.system.Object) -> None: ...
    def __getitem__(self, key: str) -> winsdk.system.Object: ...
    def __delitem__(self, key: str) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataPackagePropertySet: ...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.system.Object]]]: ...
    def get_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]]: ...
    def has_key(self, key: str) -> winsdk.system.Boolean: ...
    def insert(self, key: str, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...
    def lookup(self, key: str) -> typing.Optional[winsdk.system.Object]: ...
    def remove(self, key: str) -> None: ...

class DataPackagePropertySetView(winsdk.system.Object, typing.Mapping[str, winsdk.system.Object]):
    application_listing_uri: typing.Optional[winsdk.windows.foundation.Uri]
    application_name: str
    description: str
    file_types: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    thumbnail: typing.Optional[winsdk.windows.storage.streams.RandomAccessStreamReference]
    title: str
    content_source_application_link: typing.Optional[winsdk.windows.foundation.Uri]
    content_source_web_link: typing.Optional[winsdk.windows.foundation.Uri]
    logo_background_color: winsdk.windows.ui.Color
    package_family_name: str
    square30x30_logo: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    enterprise_id: str
    content_source_user_activity_json: str
    is_from_roaming_clipboard: winsdk.system.Boolean
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[str]: ...
    def __contains__(self, key: object) -> bool:...
    def __getitem__(self, key: str) -> winsdk.system.Object: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataPackagePropertySetView: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.system.Object]]]: ...
    def has_key(self, key: str) -> winsdk.system.Boolean: ...
    def lookup(self, key: str) -> typing.Optional[winsdk.system.Object]: ...
    def split(self) -> typing.Tuple[typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]], typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]]]: ...

class DataPackageView(winsdk.system.Object):
    available_formats: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    properties: typing.Optional[DataPackagePropertySetView]
    requested_operation: DataPackageOperation
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataPackageView: ...
    def contains(self, format_id: str) -> winsdk.system.Boolean: ...
    def get_application_link_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.Uri]: ...
    def get_bitmap_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.RandomAccessStreamReference]: ...
    def get_data_async(self, format_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Object]: ...
    def get_html_format_async(self) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    def get_resource_map_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMapView[str, winsdk.windows.storage.streams.RandomAccessStreamReference]]: ...
    def get_rtf_async(self) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    def get_storage_items_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.storage.IStorageItem]]: ...
    @typing.overload
    def get_text_async(self) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @typing.overload
    def get_text_async(self, format_id: str) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    def get_uri_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.Uri]: ...
    def get_web_link_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.Uri]: ...
    def report_operation_completed(self, value: DataPackageOperation) -> None: ...
    @typing.overload
    def request_access_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.enterprisedata.ProtectionPolicyEvaluationResult]: ...
    @typing.overload
    def request_access_async(self, enterprise_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.enterprisedata.ProtectionPolicyEvaluationResult]: ...
    def set_accepted_format_id(self, format_id: str) -> None: ...
    def unlock_and_assume_enterprise_identity(self) -> winsdk.windows.security.enterprisedata.ProtectionPolicyEvaluationResult: ...

class DataProviderDeferral(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataProviderDeferral: ...
    def complete(self) -> None: ...

class DataProviderRequest(winsdk.system.Object):
    deadline: datetime.datetime
    format_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataProviderRequest: ...
    def get_deferral(self) -> typing.Optional[DataProviderDeferral]: ...
    def set_data(self, value: typing.Optional[winsdk.system.Object]) -> None: ...

class DataRequest(winsdk.system.Object):
    data: typing.Optional[DataPackage]
    deadline: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataRequest: ...
    def fail_with_display_text(self, value: str) -> None: ...
    def get_deferral(self) -> typing.Optional[DataRequestDeferral]: ...

class DataRequestDeferral(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataRequestDeferral: ...
    def complete(self) -> None: ...

class DataRequestedEventArgs(winsdk.system.Object):
    request: typing.Optional[DataRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataRequestedEventArgs: ...

class DataTransferManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DataTransferManager: ...
    @staticmethod
    def get_for_current_view() -> typing.Optional[DataTransferManager]: ...
    @staticmethod
    def is_supported() -> winsdk.system.Boolean: ...
    @typing.overload
    @staticmethod
    def show_share_u_i() -> None: ...
    @typing.overload
    @staticmethod
    def show_share_u_i(options: typing.Optional[ShareUIOptions]) -> None: ...
    def add_data_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[DataTransferManager, DataRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_data_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_target_application_chosen(self, handler: winsdk.windows.foundation.TypedEventHandler[DataTransferManager, TargetApplicationChosenEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_target_application_chosen(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_share_providers_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[DataTransferManager, ShareProvidersRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_share_providers_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class HtmlFormatHelper(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HtmlFormatHelper: ...
    @staticmethod
    def create_html_format(html_fragment: str) -> str: ...
    @staticmethod
    def get_static_fragment(html_format: str) -> str: ...

class OperationCompletedEventArgs(winsdk.system.Object):
    operation: DataPackageOperation
    accepted_format_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> OperationCompletedEventArgs: ...

class ShareCompletedEventArgs(winsdk.system.Object):
    share_target: typing.Optional[ShareTargetInfo]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ShareCompletedEventArgs: ...

class ShareProvider(winsdk.system.Object):
    tag: typing.Optional[winsdk.system.Object]
    background_color: winsdk.windows.ui.Color
    display_icon: typing.Optional[winsdk.windows.storage.streams.RandomAccessStreamReference]
    title: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ShareProvider: ...
    def __new__(cls: typing.Type[ShareProvider], title: str, display_icon: typing.Optional[winsdk.windows.storage.streams.RandomAccessStreamReference], background_color: winsdk.windows.ui.Color, handler: typing.Optional[ShareProviderHandler]) -> ShareProvider:...

class ShareProviderOperation(winsdk.system.Object):
    data: typing.Optional[DataPackageView]
    provider: typing.Optional[ShareProvider]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ShareProviderOperation: ...
    def report_completed(self) -> None: ...

class ShareProvidersRequestedEventArgs(winsdk.system.Object):
    data: typing.Optional[DataPackageView]
    providers: typing.Optional[winsdk.windows.foundation.collections.IVector[ShareProvider]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ShareProvidersRequestedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class ShareTargetInfo(winsdk.system.Object):
    app_user_model_id: str
    share_provider: typing.Optional[ShareProvider]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ShareTargetInfo: ...

class ShareUIOptions(winsdk.system.Object):
    theme: ShareUITheme
    selection_rect: typing.Optional[typing.Optional[winsdk.windows.foundation.Rect]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ShareUIOptions: ...
    def __new__(cls: typing.Type[ShareUIOptions]) -> ShareUIOptions:...

class SharedStorageAccessManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SharedStorageAccessManager: ...
    @staticmethod
    def add_file(file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> str: ...
    @staticmethod
    def redeem_token_for_file_async(token: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.StorageFile]: ...
    @staticmethod
    def remove_file(token: str) -> None: ...

class StandardDataFormats(winsdk.system.Object):
    bitmap: typing.ClassVar[str]
    html: typing.ClassVar[str]
    rtf: typing.ClassVar[str]
    storage_items: typing.ClassVar[str]
    text: typing.ClassVar[str]
    uri: typing.ClassVar[str]
    application_link: typing.ClassVar[str]
    web_link: typing.ClassVar[str]
    user_activity_json_array: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StandardDataFormats: ...

class TargetApplicationChosenEventArgs(winsdk.system.Object):
    application_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TargetApplicationChosenEventArgs: ...

DataProviderHandler = typing.Callable[[typing.Optional[DataProviderRequest]], None]

ShareProviderHandler = typing.Callable[[typing.Optional[ShareProviderOperation]], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation.numerics
import winsdk.windows.perception.spatial

Self = typing.TypeVar('Self')

class SpatialGraphInteropFrameOfReferencePreview(winsdk.system.Object):
    coordinate_system: typing.Optional[winsdk.windows.perception.spatial.SpatialCoordinateSystem]
    coordinate_system_to_node_transform: winsdk.windows.foundation.numerics.Matrix4x4
    node_id: winsdk.system.Guid
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpatialGraphInteropFrameOfReferencePreview: ...

class SpatialGraphInteropPreview(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SpatialGraphInteropPreview: ...
    @typing.overload
    @staticmethod
    def create_coordinate_system_for_node(node_id: winsdk.system.Guid) -> typing.Optional[winsdk.windows.perception.spatial.SpatialCoordinateSystem]: ...
    @typing.overload
    @staticmethod
    def create_coordinate_system_for_node(node_id: winsdk.system.Guid, relative_position: winsdk.windows.foundation.numerics.Vector3) -> typing.Optional[winsdk.windows.perception.spatial.SpatialCoordinateSystem]: ...
    @typing.overload
    @staticmethod
    def create_coordinate_system_for_node(node_id: winsdk.system.Guid, relative_position: winsdk.windows.foundation.numerics.Vector3, relative_orientation: winsdk.windows.foundation.numerics.Quaternion) -> typing.Optional[winsdk.windows.perception.spatial.SpatialCoordinateSystem]: ...
    @staticmethod
    def create_locator_for_node(node_id: winsdk.system.Guid) -> typing.Optional[winsdk.windows.perception.spatial.SpatialLocator]: ...
    @typing.overload
    @staticmethod
    def try_create_frame_of_reference(coordinate_system: typing.Optional[winsdk.windows.perception.spatial.SpatialCoordinateSystem]) -> typing.Optional[SpatialGraphInteropFrameOfReferencePreview]: ...
    @typing.overload
    @staticmethod
    def try_create_frame_of_reference(coordinate_system: typing.Optional[winsdk.windows.perception.spatial.SpatialCoordinateSystem], relative_position: winsdk.windows.foundation.numerics.Vector3) -> typing.Optional[SpatialGraphInteropFrameOfReferencePreview]: ...
    @typing.overload
    @staticmethod
    def try_create_frame_of_reference(coordinate_system: typing.Optional[winsdk.windows.perception.spatial.SpatialCoordinateSystem], relative_position: winsdk.windows.foundation.numerics.Vector3, relative_orientation: winsdk.windows.foundation.numerics.Quaternion) -> typing.Optional[SpatialGraphInteropFrameOfReferencePreview]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.System.Diagnostics")

try:
    import winsdk.windows.data.json
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

class DiagnosticActionState(enum.IntEnum):
    INITIALIZING = 0
    DOWNLOADING = 1
    VERIFYING_TRUST = 2
    DETECTING = 3
    RESOLVING = 4
    VERIFYING_RESOLUTION = 5
    EXECUTING = 6

_ns_module._register_DiagnosticActionState(DiagnosticActionState)

DiagnosticActionResult = _ns_module.DiagnosticActionResult
DiagnosticInvoker = _ns_module.DiagnosticInvoker
ProcessCpuUsage = _ns_module.ProcessCpuUsage
ProcessCpuUsageReport = _ns_module.ProcessCpuUsageReport
ProcessDiagnosticInfo = _ns_module.ProcessDiagnosticInfo
ProcessDiskUsage = _ns_module.ProcessDiskUsage
ProcessDiskUsageReport = _ns_module.ProcessDiskUsageReport
ProcessMemoryUsage = _ns_module.ProcessMemoryUsage
ProcessMemoryUsageReport = _ns_module.ProcessMemoryUsageReport
SystemCpuUsage = _ns_module.SystemCpuUsage
SystemCpuUsageReport = _ns_module.SystemCpuUsageReport
SystemDiagnosticInfo = _ns_module.SystemDiagnosticInfo
SystemMemoryUsage = _ns_module.SystemMemoryUsage
SystemMemoryUsageReport = _ns_module.SystemMemoryUsageReport



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI")


Color = _ns_module.Color
WindowId = _ns_module.WindowId
ColorHelper = _ns_module.ColorHelper
Colors = _ns_module.Colors
UIContentRoot = _ns_module.UIContentRoot
UIContext = _ns_module.UIContext



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.storage

Self = typing.TypeVar('Self')

class ApplicationDataManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ApplicationDataManager: ...
    @staticmethod
    def create_for_package_family(package_family_name: str) -> typing.Optional[winsdk.windows.storage.ApplicationData]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Geolocation.Geofencing")

try:
    import winsdk.windows.devices.geolocation
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class GeofenceMonitorStatus(enum.IntEnum):
    READY = 0
    INITIALIZING = 1
    NO_DATA = 2
    DISABLED = 3
    NOT_INITIALIZED = 4
    NOT_AVAILABLE = 5

class GeofenceRemovalReason(enum.IntEnum):
    USED = 0
    EXPIRED = 1

class GeofenceState(enum.IntFlag):
    NONE = 0
    ENTERED = 0x1
    EXITED = 0x2
    REMOVED = 0x4

class MonitoredGeofenceStates(enum.IntFlag):
    NONE = 0
    ENTERED = 0x1
    EXITED = 0x2
    REMOVED = 0x4

_ns_module._register_GeofenceMonitorStatus(GeofenceMonitorStatus)
_ns_module._register_GeofenceRemovalReason(GeofenceRemovalReason)
_ns_module._register_GeofenceState(GeofenceState)
_ns_module._register_MonitoredGeofenceStates(MonitoredGeofenceStates)

Geofence = _ns_module.Geofence
GeofenceMonitor = _ns_module.GeofenceMonitor
GeofenceStateChangeReport = _ns_module.GeofenceStateChangeReport



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage
import winsdk.windows.storage.streams

class NodeType(enum.IntEnum):
    INVALID = 0
    ELEMENT_NODE = 1
    ATTRIBUTE_NODE = 2
    TEXT_NODE = 3
    DATA_SECTION_NODE = 4
    ENTITY_REFERENCE_NODE = 5
    ENTITY_NODE = 6
    PROCESSING_INSTRUCTION_NODE = 7
    COMMENT_NODE = 8
    DOCUMENT_NODE = 9
    DOCUMENT_TYPE_NODE = 10
    DOCUMENT_FRAGMENT_NODE = 11
    NOTATION_NODE = 12

Self = typing.TypeVar('Self')

class DtdEntity(winsdk.system.Object):
    notation_name: typing.Optional[winsdk.system.Object]
    public_id: typing.Optional[winsdk.system.Object]
    system_id: typing.Optional[winsdk.system.Object]
    prefix: typing.Optional[winsdk.system.Object]
    node_value: typing.Optional[winsdk.system.Object]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    attributes: typing.Optional[XmlNamedNodeMap]
    owner_document: typing.Optional[XmlDocument]
    child_nodes: typing.Optional[XmlNodeList]
    parent_node: typing.Optional[IXmlNode]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DtdEntity: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...

class DtdNotation(winsdk.system.Object):
    public_id: typing.Optional[winsdk.system.Object]
    system_id: typing.Optional[winsdk.system.Object]
    prefix: typing.Optional[winsdk.system.Object]
    node_value: typing.Optional[winsdk.system.Object]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    attributes: typing.Optional[XmlNamedNodeMap]
    owner_document: typing.Optional[XmlDocument]
    child_nodes: typing.Optional[XmlNodeList]
    parent_node: typing.Optional[IXmlNode]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DtdNotation: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...

class XmlAttribute(winsdk.system.Object):
    value: str
    specified: winsdk.system.Boolean
    name: str
    prefix: typing.Optional[winsdk.system.Object]
    node_value: typing.Optional[winsdk.system.Object]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    attributes: typing.Optional[XmlNamedNodeMap]
    owner_document: typing.Optional[XmlDocument]
    child_nodes: typing.Optional[XmlNodeList]
    parent_node: typing.Optional[IXmlNode]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlAttribute: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...

class XmlCDataSection(winsdk.system.Object):
    data: str
    length: winsdk.system.UInt32
    prefix: typing.Optional[winsdk.system.Object]
    node_value: typing.Optional[winsdk.system.Object]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    attributes: typing.Optional[XmlNamedNodeMap]
    owner_document: typing.Optional[XmlDocument]
    child_nodes: typing.Optional[XmlNodeList]
    parent_node: typing.Optional[IXmlNode]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlCDataSection: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def append_data(self, data: str) -> None: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def delete_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32) -> None: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def insert_data(self, offset: winsdk.system.UInt32, data: str) -> None: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32, data: str) -> None: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...
    def split_text(self, offset: winsdk.system.UInt32) -> typing.Optional[IXmlText]: ...
    def substring_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32) -> str: ...

class XmlComment(winsdk.system.Object):
    data: str
    length: winsdk.system.UInt32
    prefix: typing.Optional[winsdk.system.Object]
    node_value: typing.Optional[winsdk.system.Object]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    attributes: typing.Optional[XmlNamedNodeMap]
    owner_document: typing.Optional[XmlDocument]
    child_nodes: typing.Optional[XmlNodeList]
    parent_node: typing.Optional[IXmlNode]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlComment: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def append_data(self, data: str) -> None: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def delete_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32) -> None: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def insert_data(self, offset: winsdk.system.UInt32, data: str) -> None: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32, data: str) -> None: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...
    def substring_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32) -> str: ...

class XmlDocument(winsdk.system.Object):
    doctype: typing.Optional[XmlDocumentType]
    document_element: typing.Optional[XmlElement]
    document_uri: str
    implementation: typing.Optional[XmlDomImplementation]
    prefix: typing.Optional[winsdk.system.Object]
    node_value: typing.Optional[winsdk.system.Object]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    attributes: typing.Optional[XmlNamedNodeMap]
    child_nodes: typing.Optional[XmlNodeList]
    parent_node: typing.Optional[IXmlNode]
    owner_document: typing.Optional[XmlDocument]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlDocument: ...
    def __new__(cls: typing.Type[XmlDocument]) -> XmlDocument:...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def create_attribute(self, name: str) -> typing.Optional[XmlAttribute]: ...
    def create_attribute_n_s(self, namespace_uri: typing.Optional[winsdk.system.Object], qualified_name: str) -> typing.Optional[XmlAttribute]: ...
    def create_c_data_section(self, data: str) -> typing.Optional[XmlCDataSection]: ...
    def create_comment(self, data: str) -> typing.Optional[XmlComment]: ...
    def create_document_fragment(self) -> typing.Optional[XmlDocumentFragment]: ...
    def create_element(self, tag_name: str) -> typing.Optional[XmlElement]: ...
    def create_element_n_s(self, namespace_uri: typing.Optional[winsdk.system.Object], qualified_name: str) -> typing.Optional[XmlElement]: ...
    def create_entity_reference(self, name: str) -> typing.Optional[XmlEntityReference]: ...
    def create_processing_instruction(self, target: str, data: str) -> typing.Optional[XmlProcessingInstruction]: ...
    def create_text_node(self, data: str) -> typing.Optional[XmlText]: ...
    def get_element_by_id(self, element_id: str) -> typing.Optional[XmlElement]: ...
    def get_elements_by_tag_name(self, tag_name: str) -> typing.Optional[XmlNodeList]: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def import_node(self, node: typing.Optional[IXmlNode], deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    @typing.overload
    @staticmethod
    def load_from_file_async(file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncOperation[XmlDocument]: ...
    @typing.overload
    @staticmethod
    def load_from_file_async(file: typing.Optional[winsdk.windows.storage.IStorageFile], load_settings: typing.Optional[XmlLoadSettings]) -> winsdk.windows.foundation.IAsyncOperation[XmlDocument]: ...
    @typing.overload
    @staticmethod
    def load_from_uri_async(uri: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncOperation[XmlDocument]: ...
    @typing.overload
    @staticmethod
    def load_from_uri_async(uri: typing.Optional[winsdk.windows.foundation.Uri], load_settings: typing.Optional[XmlLoadSettings]) -> winsdk.windows.foundation.IAsyncOperation[XmlDocument]: ...
    @typing.overload
    def load_xml(self, xml: str) -> None: ...
    @typing.overload
    def load_xml(self, xml: str, load_settings: typing.Optional[XmlLoadSettings]) -> None: ...
    @typing.overload
    def load_xml_from_buffer(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> None: ...
    @typing.overload
    def load_xml_from_buffer(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer], load_settings: typing.Optional[XmlLoadSettings]) -> None: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def save_to_file_async(self, file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncAction: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...

class XmlDocumentFragment(winsdk.system.Object):
    prefix: typing.Optional[winsdk.system.Object]
    node_value: typing.Optional[winsdk.system.Object]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    attributes: typing.Optional[XmlNamedNodeMap]
    owner_document: typing.Optional[XmlDocument]
    parent_node: typing.Optional[IXmlNode]
    child_nodes: typing.Optional[XmlNodeList]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlDocumentFragment: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...

class XmlDocumentType(winsdk.system.Object):
    entities: typing.Optional[XmlNamedNodeMap]
    name: str
    notations: typing.Optional[XmlNamedNodeMap]
    prefix: typing.Optional[winsdk.system.Object]
    node_value: typing.Optional[winsdk.system.Object]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    attributes: typing.Optional[XmlNamedNodeMap]
    owner_document: typing.Optional[XmlDocument]
    child_nodes: typing.Optional[XmlNodeList]
    parent_node: typing.Optional[IXmlNode]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlDocumentType: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...

class XmlDomImplementation(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlDomImplementation: ...
    def has_feature(self, feature: str, version: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...

class XmlElement(winsdk.system.Object):
    tag_name: str
    prefix: typing.Optional[winsdk.system.Object]
    node_value: typing.Optional[winsdk.system.Object]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    namespace_uri: typing.Optional[winsdk.system.Object]
    node_type: NodeType
    node_name: str
    attributes: typing.Optional[XmlNamedNodeMap]
    owner_document: typing.Optional[XmlDocument]
    parent_node: typing.Optional[IXmlNode]
    child_nodes: typing.Optional[XmlNodeList]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlElement: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def get_attribute(self, attribute_name: str) -> str: ...
    def get_attribute_n_s(self, namespace_uri: typing.Optional[winsdk.system.Object], local_name: str) -> str: ...
    def get_attribute_node(self, attribute_name: str) -> typing.Optional[XmlAttribute]: ...
    def get_attribute_node_n_s(self, namespace_uri: typing.Optional[winsdk.system.Object], local_name: str) -> typing.Optional[XmlAttribute]: ...
    def get_elements_by_tag_name(self, tag_name: str) -> typing.Optional[XmlNodeList]: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def normalize(self) -> None: ...
    def remove_attribute(self, attribute_name: str) -> None: ...
    def remove_attribute_n_s(self, namespace_uri: typing.Optional[winsdk.system.Object], local_name: str) -> None: ...
    def remove_attribute_node(self, attribute_node: typing.Optional[XmlAttribute]) -> typing.Optional[XmlAttribute]: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...
    def set_attribute(self, attribute_name: str, attribute_value: str) -> None: ...
    def set_attribute_n_s(self, namespace_uri: typing.Optional[winsdk.system.Object], qualified_name: str, value: str) -> None: ...
    def set_attribute_node(self, new_attribute: typing.Optional[XmlAttribute]) -> typing.Optional[XmlAttribute]: ...
    def set_attribute_node_n_s(self, new_attribute: typing.Optional[XmlAttribute]) -> typing.Optional[XmlAttribute]: ...

class XmlEntityReference(winsdk.system.Object):
    prefix: typing.Optional[winsdk.system.Object]
    node_value: typing.Optional[winsdk.system.Object]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    attributes: typing.Optional[XmlNamedNodeMap]
    owner_document: typing.Optional[XmlDocument]
    parent_node: typing.Optional[IXmlNode]
    child_nodes: typing.Optional[XmlNodeList]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlEntityReference: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...

class XmlLoadSettings(winsdk.system.Object):
    validate_on_parse: winsdk.system.Boolean
    resolve_externals: winsdk.system.Boolean
    prohibit_dtd: winsdk.system.Boolean
    max_element_depth: winsdk.system.UInt32
    element_content_white_space: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlLoadSettings: ...
    def __new__(cls: typing.Type[XmlLoadSettings]) -> XmlLoadSettings:...

class XmlNamedNodeMap(winsdk.system.Object, typing.Sequence[IXmlNode]):
    length: winsdk.system.UInt32
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: int) -> IXmlNode: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winsdk.system.Array[IXmlNode]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlNamedNodeMap: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[IXmlNode]]: ...
    def get_at(self, index: winsdk.system.UInt32) -> typing.Optional[IXmlNode]: ...
    def get_many(self, start_index: winsdk.system.UInt32, items: winsdk.system.Array[IXmlNode]) -> winsdk.system.UInt32: ...
    def get_named_item(self, name: str) -> typing.Optional[IXmlNode]: ...
    def get_named_item_n_s(self, namespace_uri: typing.Optional[winsdk.system.Object], name: str) -> typing.Optional[IXmlNode]: ...
    def index_of(self, value: typing.Optional[IXmlNode]) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.UInt32]: ...
    def item(self, index: winsdk.system.UInt32) -> typing.Optional[IXmlNode]: ...
    def remove_named_item(self, name: str) -> typing.Optional[IXmlNode]: ...
    def remove_named_item_n_s(self, namespace_uri: typing.Optional[winsdk.system.Object], name: str) -> typing.Optional[IXmlNode]: ...
    def set_named_item(self, node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def set_named_item_n_s(self, node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...

class XmlNodeList(winsdk.system.Object, typing.Sequence[IXmlNode]):
    length: winsdk.system.UInt32
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: int) -> IXmlNode: ...
    @typing.overload
    def __getitem__(self, index: slice) -> winsdk.system.Array[IXmlNode]: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlNodeList: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[IXmlNode]]: ...
    def get_at(self, index: winsdk.system.UInt32) -> typing.Optional[IXmlNode]: ...
    def get_many(self, start_index: winsdk.system.UInt32, items: winsdk.system.Array[IXmlNode]) -> winsdk.system.UInt32: ...
    def index_of(self, value: typing.Optional[IXmlNode]) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.UInt32]: ...
    def item(self, index: winsdk.system.UInt32) -> typing.Optional[IXmlNode]: ...

class XmlProcessingInstruction(winsdk.system.Object):
    prefix: typing.Optional[winsdk.system.Object]
    node_value: typing.Optional[winsdk.system.Object]
    attributes: typing.Optional[XmlNamedNodeMap]
    first_child: typing.Optional[IXmlNode]
    child_nodes: typing.Optional[XmlNodeList]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    owner_document: typing.Optional[XmlDocument]
    parent_node: typing.Optional[IXmlNode]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    data: str
    target: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlProcessingInstruction: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...

class XmlText(winsdk.system.Object):
    data: str
    length: winsdk.system.UInt32
    prefix: typing.Optional[winsdk.system.Object]
    node_value: typing.Optional[winsdk.system.Object]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    attributes: typing.Optional[XmlNamedNodeMap]
    owner_document: typing.Optional[XmlDocument]
    child_nodes: typing.Optional[XmlNodeList]
    parent_node: typing.Optional[IXmlNode]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> XmlText: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def append_data(self, data: str) -> None: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def delete_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32) -> None: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def insert_data(self, offset: winsdk.system.UInt32, data: str) -> None: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32, data: str) -> None: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...
    def split_text(self, offset: winsdk.system.UInt32) -> typing.Optional[IXmlText]: ...
    def substring_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32) -> str: ...

class IXmlCharacterData(winsdk.system.Object):
    data: str
    length: winsdk.system.UInt32
    attributes: typing.Optional[XmlNamedNodeMap]
    child_nodes: typing.Optional[XmlNodeList]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    node_value: typing.Optional[winsdk.system.Object]
    owner_document: typing.Optional[XmlDocument]
    parent_node: typing.Optional[IXmlNode]
    prefix: typing.Optional[winsdk.system.Object]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IXmlCharacterData: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def append_data(self, data: str) -> None: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def delete_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32) -> None: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def insert_data(self, offset: winsdk.system.UInt32, data: str) -> None: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32, data: str) -> None: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...
    def substring_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32) -> str: ...

class IXmlNode(winsdk.system.Object):
    attributes: typing.Optional[XmlNamedNodeMap]
    child_nodes: typing.Optional[XmlNodeList]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    node_value: typing.Optional[winsdk.system.Object]
    owner_document: typing.Optional[XmlDocument]
    parent_node: typing.Optional[IXmlNode]
    prefix: typing.Optional[winsdk.system.Object]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IXmlNode: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...

class IXmlNodeSelector(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IXmlNodeSelector: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...

class IXmlNodeSerializer(winsdk.system.Object):
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IXmlNodeSerializer: ...
    def get_xml(self) -> str: ...

class IXmlText(winsdk.system.Object):
    data: str
    length: winsdk.system.UInt32
    attributes: typing.Optional[XmlNamedNodeMap]
    child_nodes: typing.Optional[XmlNodeList]
    first_child: typing.Optional[IXmlNode]
    last_child: typing.Optional[IXmlNode]
    local_name: typing.Optional[winsdk.system.Object]
    namespace_uri: typing.Optional[winsdk.system.Object]
    next_sibling: typing.Optional[IXmlNode]
    node_name: str
    node_type: NodeType
    node_value: typing.Optional[winsdk.system.Object]
    owner_document: typing.Optional[XmlDocument]
    parent_node: typing.Optional[IXmlNode]
    prefix: typing.Optional[winsdk.system.Object]
    previous_sibling: typing.Optional[IXmlNode]
    inner_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IXmlText: ...
    def append_child(self, new_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def append_data(self, data: str) -> None: ...
    def clone_node(self, deep: winsdk.system.Boolean) -> typing.Optional[IXmlNode]: ...
    def delete_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32) -> None: ...
    def get_xml(self) -> str: ...
    def has_child_nodes(self) -> winsdk.system.Boolean: ...
    def insert_before(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def insert_data(self, offset: winsdk.system.UInt32, data: str) -> None: ...
    def normalize(self) -> None: ...
    def remove_child(self, child_node: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_child(self, new_child: typing.Optional[IXmlNode], reference_child: typing.Optional[IXmlNode]) -> typing.Optional[IXmlNode]: ...
    def replace_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32, data: str) -> None: ...
    def select_nodes(self, xpath: str) -> typing.Optional[XmlNodeList]: ...
    def select_nodes_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[XmlNodeList]: ...
    def select_single_node(self, xpath: str) -> typing.Optional[IXmlNode]: ...
    def select_single_node_n_s(self, xpath: str, namespaces: typing.Optional[winsdk.system.Object]) -> typing.Optional[IXmlNode]: ...
    def split_text(self, offset: winsdk.system.UInt32) -> typing.Optional[IXmlText]: ...
    def substring_data(self, offset: winsdk.system.UInt32, count: winsdk.system.UInt32) -> str: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.system
import winsdk.windows.web.http

class StoreCanLicenseStatus(enum.IntEnum):
    NOT_LICENSABLE_TO_USER = 0
    LICENSABLE = 1
    LICENSE_ACTION_NOT_APPLICABLE_TO_PRODUCT = 2
    NETWORK_ERROR = 3
    SERVER_ERROR = 4

class StoreConsumableStatus(enum.IntEnum):
    SUCCEEDED = 0
    INSUFFICENT_QUANTITY = 1
    NETWORK_ERROR = 2
    SERVER_ERROR = 3

class StoreDurationUnit(enum.IntEnum):
    MINUTE = 0
    HOUR = 1
    DAY = 2
    WEEK = 3
    MONTH = 4
    YEAR = 5

class StorePackageUpdateState(enum.IntEnum):
    PENDING = 0
    DOWNLOADING = 1
    DEPLOYING = 2
    COMPLETED = 3
    CANCELED = 4
    OTHER_ERROR = 5
    ERROR_LOW_BATTERY = 6
    ERROR_WI_FI_RECOMMENDED = 7
    ERROR_WI_FI_REQUIRED = 8

class StorePurchaseStatus(enum.IntEnum):
    SUCCEEDED = 0
    ALREADY_PURCHASED = 1
    NOT_PURCHASED = 2
    NETWORK_ERROR = 3
    SERVER_ERROR = 4

class StoreQueueItemExtendedState(enum.IntEnum):
    ACTIVE_PENDING = 0
    ACTIVE_STARTING = 1
    ACTIVE_ACQUIRING_LICENSE = 2
    ACTIVE_DOWNLOADING = 3
    ACTIVE_RESTORING_DATA = 4
    ACTIVE_INSTALLING = 5
    COMPLETED = 6
    CANCELED = 7
    PAUSED = 8
    ERROR = 9
    PAUSED_PACKAGES_IN_USE = 10
    PAUSED_LOW_BATTERY = 11
    PAUSED_WI_FI_RECOMMENDED = 12
    PAUSED_WI_FI_REQUIRED = 13
    PAUSED_READY_TO_INSTALL = 14

class StoreQueueItemKind(enum.IntEnum):
    INSTALL = 0
    UPDATE = 1
    REPAIR = 2

class StoreQueueItemState(enum.IntEnum):
    ACTIVE = 0
    COMPLETED = 1
    CANCELED = 2
    ERROR = 3
    PAUSED = 4

class StoreRateAndReviewStatus(enum.IntEnum):
    SUCCEEDED = 0
    CANCELED_BY_USER = 1
    NETWORK_ERROR = 2
    ERROR = 3

class StoreUninstallStorePackageStatus(enum.IntEnum):
    SUCCEEDED = 0
    CANCELED_BY_USER = 1
    NETWORK_ERROR = 2
    UNINSTALL_NOT_APPLICABLE = 3
    ERROR = 4

Self = typing.TypeVar('Self')

class StorePackageUpdateStatus:
    package_family_name: str
    package_download_size_in_bytes: winsdk.system.UInt64
    package_bytes_downloaded: winsdk.system.UInt64
    package_download_progress: winsdk.system.Double
    total_download_progress: winsdk.system.Double
    package_update_state: StorePackageUpdateState
    def __new__(cls: typing.Type[StorePackageUpdateStatus], package_family_name: str, package_download_size_in_bytes: winsdk.system.UInt64, package_bytes_downloaded: winsdk.system.UInt64, package_download_progress: winsdk.system.Double, total_download_progress: winsdk.system.Double, package_update_state: StorePackageUpdateState) -> StorePackageUpdateStatus: ...

class StoreAcquireLicenseResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    store_package_license: typing.Optional[StorePackageLicense]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreAcquireLicenseResult: ...

class StoreAppLicense(winsdk.system.Object):
    add_on_licenses: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, StoreLicense]]
    expiration_date: datetime.datetime
    extended_json_data: str
    is_active: winsdk.system.Boolean
    is_trial: winsdk.system.Boolean
    is_trial_owned_by_this_user: winsdk.system.Boolean
    sku_store_id: str
    trial_time_remaining: datetime.timedelta
    trial_unique_id: str
    is_disc_license: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreAppLicense: ...

class StoreAvailability(winsdk.system.Object):
    end_date: datetime.datetime
    extended_json_data: str
    price: typing.Optional[StorePrice]
    store_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreAvailability: ...
    @typing.overload
    def request_purchase_async(self) -> winsdk.windows.foundation.IAsyncOperation[StorePurchaseResult]: ...
    @typing.overload
    def request_purchase_async(self, store_purchase_properties: typing.Optional[StorePurchaseProperties]) -> winsdk.windows.foundation.IAsyncOperation[StorePurchaseResult]: ...

class StoreCanAcquireLicenseResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    licensable_sku: str
    status: StoreCanLicenseStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreCanAcquireLicenseResult: ...

class StoreCollectionData(winsdk.system.Object):
    acquired_date: datetime.datetime
    campaign_id: str
    developer_offer_id: str
    end_date: datetime.datetime
    extended_json_data: str
    is_trial: winsdk.system.Boolean
    start_date: datetime.datetime
    trial_time_remaining: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreCollectionData: ...

class StoreConsumableResult(winsdk.system.Object):
    balance_remaining: winsdk.system.UInt32
    extended_error: winsdk.windows.foundation.HResult
    status: StoreConsumableStatus
    tracking_id: winsdk.system.Guid
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreConsumableResult: ...

class StoreContext(winsdk.system.Object):
    user: typing.Optional[winsdk.windows.system.User]
    can_silently_download_store_package_updates: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreContext: ...
    def acquire_store_license_for_optional_package_async(self, optional_package: typing.Optional[winsdk.windows.applicationmodel.Package]) -> winsdk.windows.foundation.IAsyncOperation[StoreAcquireLicenseResult]: ...
    def can_acquire_store_license_async(self, product_store_id: str) -> winsdk.windows.foundation.IAsyncOperation[StoreCanAcquireLicenseResult]: ...
    def can_acquire_store_license_for_optional_package_async(self, optional_package: typing.Optional[winsdk.windows.applicationmodel.Package]) -> winsdk.windows.foundation.IAsyncOperation[StoreCanAcquireLicenseResult]: ...
    def download_and_install_store_packages_async(self, store_ids: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[StorePackageUpdateResult, StorePackageUpdateStatus]: ...
    def find_store_product_for_package_async(self, product_kinds: typing.Iterable[str], package: typing.Optional[winsdk.windows.applicationmodel.Package]) -> winsdk.windows.foundation.IAsyncOperation[StoreProductResult]: ...
    def get_app_and_optional_store_package_updates_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StorePackageUpdate]]: ...
    def get_app_license_async(self) -> winsdk.windows.foundation.IAsyncOperation[StoreAppLicense]: ...
    def get_associated_store_products_async(self, product_kinds: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[StoreProductQueryResult]: ...
    def get_associated_store_products_with_paging_async(self, product_kinds: typing.Iterable[str], max_items_to_retrieve_per_page: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[StoreProductPagedQueryResult]: ...
    def get_associated_store_queue_items_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StoreQueueItem]]: ...
    def get_consumable_balance_remaining_async(self, product_store_id: str) -> winsdk.windows.foundation.IAsyncOperation[StoreConsumableResult]: ...
    def get_customer_collections_id_async(self, service_ticket: str, publisher_user_id: str) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    def get_customer_purchase_id_async(self, service_ticket: str, publisher_user_id: str) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @staticmethod
    def get_default() -> typing.Optional[StoreContext]: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[StoreContext]: ...
    def get_store_product_for_current_app_async(self) -> winsdk.windows.foundation.IAsyncOperation[StoreProductResult]: ...
    @typing.overload
    def get_store_products_async(self, product_kinds: typing.Iterable[str], store_ids: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[StoreProductQueryResult]: ...
    @typing.overload
    def get_store_products_async(self, product_kinds: typing.Iterable[str], store_ids: typing.Iterable[str], store_product_options: typing.Optional[StoreProductOptions]) -> winsdk.windows.foundation.IAsyncOperation[StoreProductQueryResult]: ...
    def get_store_queue_items_async(self, store_ids: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StoreQueueItem]]: ...
    def get_user_collection_async(self, product_kinds: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[StoreProductQueryResult]: ...
    def get_user_collection_with_paging_async(self, product_kinds: typing.Iterable[str], max_items_to_retrieve_per_page: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[StoreProductPagedQueryResult]: ...
    def report_consumable_fulfillment_async(self, product_store_id: str, quantity: winsdk.system.UInt32, tracking_id: winsdk.system.Guid) -> winsdk.windows.foundation.IAsyncOperation[StoreConsumableResult]: ...
    def request_download_and_install_store_package_updates_async(self, store_package_updates: typing.Iterable[StorePackageUpdate]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[StorePackageUpdateResult, StorePackageUpdateStatus]: ...
    @typing.overload
    def request_download_and_install_store_packages_async(self, store_ids: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[StorePackageUpdateResult, StorePackageUpdateStatus]: ...
    @typing.overload
    def request_download_and_install_store_packages_async(self, store_ids: typing.Iterable[str], store_package_install_options: typing.Optional[StorePackageInstallOptions]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[StorePackageUpdateResult, StorePackageUpdateStatus]: ...
    def request_download_store_package_updates_async(self, store_package_updates: typing.Iterable[StorePackageUpdate]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[StorePackageUpdateResult, StorePackageUpdateStatus]: ...
    @typing.overload
    def request_purchase_async(self, store_id: str) -> winsdk.windows.foundation.IAsyncOperation[StorePurchaseResult]: ...
    @typing.overload
    def request_purchase_async(self, store_id: str, store_purchase_properties: typing.Optional[StorePurchaseProperties]) -> winsdk.windows.foundation.IAsyncOperation[StorePurchaseResult]: ...
    def request_rate_and_review_app_async(self) -> winsdk.windows.foundation.IAsyncOperation[StoreRateAndReviewResult]: ...
    def request_uninstall_store_package_async(self, package: typing.Optional[winsdk.windows.applicationmodel.Package]) -> winsdk.windows.foundation.IAsyncOperation[StoreUninstallStorePackageResult]: ...
    def request_uninstall_store_package_by_store_id_async(self, store_id: str) -> winsdk.windows.foundation.IAsyncOperation[StoreUninstallStorePackageResult]: ...
    def set_install_order_for_associated_store_queue_items_async(self, items: typing.Iterable[StoreQueueItem]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StoreQueueItem]]: ...
    def try_silent_download_and_install_store_package_updates_async(self, store_package_updates: typing.Iterable[StorePackageUpdate]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[StorePackageUpdateResult, StorePackageUpdateStatus]: ...
    def try_silent_download_store_package_updates_async(self, store_package_updates: typing.Iterable[StorePackageUpdate]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[StorePackageUpdateResult, StorePackageUpdateStatus]: ...
    def uninstall_store_package_async(self, package: typing.Optional[winsdk.windows.applicationmodel.Package]) -> winsdk.windows.foundation.IAsyncOperation[StoreUninstallStorePackageResult]: ...
    def uninstall_store_package_by_store_id_async(self, store_id: str) -> winsdk.windows.foundation.IAsyncOperation[StoreUninstallStorePackageResult]: ...
    def add_offline_licenses_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[StoreContext, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_offline_licenses_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class StoreImage(winsdk.system.Object):
    caption: str
    height: winsdk.system.UInt32
    image_purpose_tag: str
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    width: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreImage: ...

class StoreLicense(winsdk.system.Object):
    expiration_date: datetime.datetime
    extended_json_data: str
    in_app_offer_token: str
    is_active: winsdk.system.Boolean
    sku_store_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreLicense: ...

class StorePackageInstallOptions(winsdk.system.Object):
    allow_forced_app_restart: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorePackageInstallOptions: ...
    def __new__(cls: typing.Type[StorePackageInstallOptions]) -> StorePackageInstallOptions:...

class StorePackageLicense(winsdk.system.Object):
    is_valid: winsdk.system.Boolean
    package: typing.Optional[winsdk.windows.applicationmodel.Package]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorePackageLicense: ...
    def close(self) -> None: ...
    def release_license(self) -> None: ...
    def add_license_lost(self, handler: winsdk.windows.foundation.TypedEventHandler[StorePackageLicense, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_license_lost(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class StorePackageUpdate(winsdk.system.Object):
    mandatory: winsdk.system.Boolean
    package: typing.Optional[winsdk.windows.applicationmodel.Package]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorePackageUpdate: ...

class StorePackageUpdateResult(winsdk.system.Object):
    overall_state: StorePackageUpdateState
    store_package_update_statuses: typing.Optional[winsdk.windows.foundation.collections.IVectorView[StorePackageUpdateStatus]]
    store_queue_items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[StoreQueueItem]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorePackageUpdateResult: ...

class StorePrice(winsdk.system.Object):
    currency_code: str
    formatted_base_price: str
    formatted_price: str
    formatted_recurrence_price: str
    is_on_sale: winsdk.system.Boolean
    sale_end_date: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorePrice: ...

class StoreProduct(winsdk.system.Object):
    description: str
    extended_json_data: str
    has_digital_download: winsdk.system.Boolean
    images: typing.Optional[winsdk.windows.foundation.collections.IVectorView[StoreImage]]
    in_app_offer_token: str
    is_in_user_collection: winsdk.system.Boolean
    keywords: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    language: str
    link_uri: typing.Optional[winsdk.windows.foundation.Uri]
    price: typing.Optional[StorePrice]
    product_kind: str
    skus: typing.Optional[winsdk.windows.foundation.collections.IVectorView[StoreSku]]
    store_id: str
    title: str
    videos: typing.Optional[winsdk.windows.foundation.collections.IVectorView[StoreVideo]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreProduct: ...
    def get_is_any_sku_installed_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @typing.overload
    def request_purchase_async(self) -> winsdk.windows.foundation.IAsyncOperation[StorePurchaseResult]: ...
    @typing.overload
    def request_purchase_async(self, store_purchase_properties: typing.Optional[StorePurchaseProperties]) -> winsdk.windows.foundation.IAsyncOperation[StorePurchaseResult]: ...

class StoreProductOptions(winsdk.system.Object):
    action_filters: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreProductOptions: ...
    def __new__(cls: typing.Type[StoreProductOptions]) -> StoreProductOptions:...

class StoreProductPagedQueryResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    has_more_results: winsdk.system.Boolean
    products: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, StoreProduct]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreProductPagedQueryResult: ...
    def get_next_async(self) -> winsdk.windows.foundation.IAsyncOperation[StoreProductPagedQueryResult]: ...

class StoreProductQueryResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    products: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, StoreProduct]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreProductQueryResult: ...

class StoreProductResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    product: typing.Optional[StoreProduct]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreProductResult: ...

class StorePurchaseProperties(winsdk.system.Object):
    name: str
    extended_json_data: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorePurchaseProperties: ...
    @typing.overload
    def __new__(cls: typing.Type[StorePurchaseProperties], name: str) -> StorePurchaseProperties:...
    @typing.overload
    def __new__(cls: typing.Type[StorePurchaseProperties]) -> StorePurchaseProperties:...

class StorePurchaseResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    status: StorePurchaseStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorePurchaseResult: ...

class StoreQueueItem(winsdk.system.Object):
    install_kind: StoreQueueItemKind
    package_family_name: str
    product_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreQueueItem: ...
    def cancel_install_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def get_current_status(self) -> typing.Optional[StoreQueueItemStatus]: ...
    def pause_install_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def resume_install_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def add_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[StoreQueueItem, StoreQueueItemCompletedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_status_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[StoreQueueItem, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_status_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class StoreQueueItemCompletedEventArgs(winsdk.system.Object):
    status: typing.Optional[StoreQueueItemStatus]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreQueueItemCompletedEventArgs: ...

class StoreQueueItemStatus(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    package_install_extended_state: StoreQueueItemExtendedState
    package_install_state: StoreQueueItemState
    update_status: StorePackageUpdateStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreQueueItemStatus: ...

class StoreRateAndReviewResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    extended_json_data: str
    status: StoreRateAndReviewStatus
    was_updated: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreRateAndReviewResult: ...

class StoreRequestHelper(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreRequestHelper: ...
    @staticmethod
    def send_request_async(context: typing.Optional[StoreContext], request_kind: winsdk.system.UInt32, parameters_as_json: str) -> winsdk.windows.foundation.IAsyncOperation[StoreSendRequestResult]: ...

class StoreSendRequestResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    response: str
    http_status_code: winsdk.windows.web.http.HttpStatusCode
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreSendRequestResult: ...

class StoreSku(winsdk.system.Object):
    availabilities: typing.Optional[winsdk.windows.foundation.collections.IVectorView[StoreAvailability]]
    bundled_skus: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    collection_data: typing.Optional[StoreCollectionData]
    custom_developer_data: str
    description: str
    extended_json_data: str
    images: typing.Optional[winsdk.windows.foundation.collections.IVectorView[StoreImage]]
    is_in_user_collection: winsdk.system.Boolean
    is_subscription: winsdk.system.Boolean
    is_trial: winsdk.system.Boolean
    language: str
    price: typing.Optional[StorePrice]
    store_id: str
    subscription_info: typing.Optional[StoreSubscriptionInfo]
    title: str
    videos: typing.Optional[winsdk.windows.foundation.collections.IVectorView[StoreVideo]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreSku: ...
    def get_is_installed_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @typing.overload
    def request_purchase_async(self) -> winsdk.windows.foundation.IAsyncOperation[StorePurchaseResult]: ...
    @typing.overload
    def request_purchase_async(self, store_purchase_properties: typing.Optional[StorePurchaseProperties]) -> winsdk.windows.foundation.IAsyncOperation[StorePurchaseResult]: ...

class StoreSubscriptionInfo(winsdk.system.Object):
    billing_period: winsdk.system.UInt32
    billing_period_unit: StoreDurationUnit
    has_trial_period: winsdk.system.Boolean
    trial_period: winsdk.system.UInt32
    trial_period_unit: StoreDurationUnit
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreSubscriptionInfo: ...

class StoreUninstallStorePackageResult(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    status: StoreUninstallStorePackageStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreUninstallStorePackageResult: ...

class StoreVideo(winsdk.system.Object):
    caption: str
    height: winsdk.system.UInt32
    preview_image: typing.Optional[StoreImage]
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    video_purpose_tag: str
    width: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StoreVideo: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Foundation.Metadata")

class AttributeTargets(enum.IntFlag):
    ALL = 0xffffffff
    DELEGATE = 0x1
    ENUM = 0x2
    EVENT = 0x4
    FIELD = 0x8
    INTERFACE = 0x10
    METHOD = 0x40
    PARAMETER = 0x80
    PROPERTY = 0x100
    RUNTIME_CLASS = 0x200
    STRUCT = 0x400
    INTERFACE_IMPL = 0x800
    API_CONTRACT = 0x2000

class CompositionType(enum.IntEnum):
    PROTECTED = 1
    PUBLIC = 2

class DeprecationType(enum.IntEnum):
    DEPRECATE = 0
    REMOVE = 1

class FeatureStage(enum.IntEnum):
    ALWAYS_DISABLED = 0
    DISABLED_BY_DEFAULT = 1
    ENABLED_BY_DEFAULT = 2
    ALWAYS_ENABLED = 3

class GCPressureAmount(enum.IntEnum):
    LOW = 0
    MEDIUM = 1
    HIGH = 2

class MarshalingType(enum.IntEnum):
    NONE = 1
    AGILE = 2
    STANDARD = 3
    INVALID_MARSHALING = 0

class Platform(enum.IntEnum):
    WINDOWS = 0
    WINDOWS_PHONE = 1

class ThreadingModel(enum.IntEnum):
    S_T_A = 1
    M_T_A = 2
    BOTH = 3
    INVALID_THREADING = 0

_ns_module._register_AttributeTargets(AttributeTargets)
_ns_module._register_CompositionType(CompositionType)
_ns_module._register_DeprecationType(DeprecationType)
_ns_module._register_FeatureStage(FeatureStage)
_ns_module._register_GCPressureAmount(GCPressureAmount)
_ns_module._register_MarshalingType(MarshalingType)
_ns_module._register_Platform(Platform)
_ns_module._register_ThreadingModel(ThreadingModel)

ApiInformation = _ns_module.ApiInformation
